@@ -35,7 +35,7 @@ class SettingsDialog : public KPageDialog
 
     public Q_SLOTS:
 
-    void accept() Q_DECL_OVERRIDE;
+    void accept() override;
 
     private Q_SLOTS:
 
