@@ -45,11 +45,11 @@ class SpectacleConfig : public QObject
 
     QString defaultFilename() const;
     QString defaultTimestampTemplate() const;
-    
+
     QUrl lastSaveAsLocation() const;
     QUrl lastSaveLocation() const;
 
-     enum PrintKeyActionRunning : int {
+    enum PrintKeyActionRunning : int {
         TakeNewScreenshot = 0,
         StartNewInstance,
         FocusWindow
@@ -126,6 +126,12 @@ class SpectacleConfig : public QObject
     QUrl defaultSaveLocation() const;
     void setDefaultSaveLocation(const QUrl &location);
 
+    bool copyImageToClipboard() const;
+    void setCopyImageToClipboard(bool enabled);
+
+    bool autoSaveImage() const;
+    void setAutoSaveImage(bool enabled);
+
     bool copySaveLocationToClipboard() const;
     void setCopySaveLocationToClipboard(bool enabled);
 
